@@ -151,7 +151,7 @@ class ListResource(Resource):
     def __len__(self):
         self.fetch()
 
-        return self._page_end - self._page_start + 1
+        return self._page_end - self._page_start
 
     def __iter__(self):
         return self
@@ -406,6 +406,10 @@ class Client(object):
                 except ValueError:
                     raise exceptions.RequestError("Errror requesting %s to '%s'. Status code: %s" % (method, url, response.status_code), http_code=response.status_code)
 
+        print
+        print response.content
+        print
+
         try:
             return json.loads(response.content)
         except ValueError, e:
